export default {
    labelIdle: `Arrossega i deixa anar els teus fitxers o <span class="filepond--label-action"> Navega </span>`,
    labelInvalidField: `El camp conté fitxers invàlids`,
    labelFileWaitingForSize: `Esperant mida`,
    labelFileSizeNotAvailable: `Mida no disponible`,
    labelFileLoading: `Carregant`,
    labelFileLoadError: `Error durant la càrrega`,
    labelFileProcessing: `Pujant`,
    labelFileProcessingComplete: `Pujada completada`,
    labelFileProcessingAborted: `Pujada cancel·lada`,
    labelFileProcessingError: `Error durant la pujada`,
    labelFileProcessingRevertError: `Error durant la reversió`,
    labelFileRemoveError: `Error durant l'eliminació`,
    labelTapToCancel: `toca per cancel·lar`,
    labelTapToRetry: `toca per reintentar`,
    labelTapToUndo: `toca per desfer`,
    labelButtonRemoveItem: `Eliminar`,
    labelButtonAbortItemLoad: `Cancel·lar`,
    labelButtonRetryItemLoad: `Reintentar`,
    labelButtonAbortItemProcessing: `Cancel·lar`,
    labelButtonUndoItemProcessing: `Desfer`,
    labelButtonRetryItemProcessing: `Reintentar`,
    labelButtonProcessItem: `Pujar`,
    labelMaxFileSizeExceeded: `El fitxer és massa gran`,
    labelMaxFileSize: `La mida màxima del fitxer és {filesize}`,
    labelMaxTotalFileSizeExceeded: `Mida màxima total excedida`,
    labelMaxTotalFileSize: `La mida màxima total del fitxer és {filesize}`,
    labelFileTypeNotAllowed: `Fitxer de tipus invàlid`,
    fileValidateTypeLabelExpectedTypes: `Espera {allButLastType} o {lastType}`,
    imageValidateSizeLabelFormatError: `Tipus d'imatge no suportada`,
    imageValidateSizeLabelImageSizeTooSmall: `La imatge és massa petita`,
    imageValidateSizeLabelImageSizeTooBig: `La imatge és massa gran`,
    imageValidateSizeLabelExpectedMinSize: `La mida mínima és {minWidth} x {minHeight}`,
    imageValidateSizeLabelExpectedMaxSize: `La mida màxima és {maxWidth} x {maxHeight}`,
    imageValidateSizeLabelImageResolutionTooLow: `La resolució és massa baixa`,
    imageValidateSizeLabelImageResolutionTooHigh: `La resolució és massa alta`,
    imageValidateSizeLabelExpectedMinResolution: `La resolució mínima és {minResolution}`,
    imageValidateSizeLabelExpectedMaxResolution: `La resolució màxima és {maxResolution}`,
}
