export default {
    labelIdle: 'Dosyanızı Sürükleyin & Bırakın ya da <span class="filepond--label-action"> Seçin </span>',
    labelInvalidField: 'Alan geçersiz dosyalar içeriyor',
    labelFileWaitingForSize: 'Boyut hesaplanıyor',
    labelFileSizeNotAvailable: 'Boyut mevcut değil',
    labelFileLoading: 'Yükleniyor',
    labelFileLoadError: 'Yükleme sırasında hata oluştu',
    labelFileProcessing: 'Yükleniyor',
    labelFileProcessingComplete: 'Yükleme tamamlandı',
    labelFileProcessingAborted: 'Yükleme iptal edildi',
    labelFileProcessingError: 'Yüklerken hata oluştu',
    labelFileProcessingRevertError: 'Geri çekerken hata oluştu',
    labelFileRemoveError: 'Kaldırırken hata oluştu',
    labelTapToCancel: 'İptal etmek için tıklayın',
    labelTapToRetry: 'Tekrar denemek için tıklayın',
    labelTapToUndo: 'Geri almak için tıklayın',
    labelButtonRemoveItem: 'Kaldır',
    labelButtonAbortItemLoad: 'İptal Et',
    labelButtonRetryItemLoad: 'Tekrar dene',
    labelButtonAbortItemProcessing: 'İptal et',
    labelButtonUndoItemProcessing: 'Geri Al',
    labelButtonRetryItemProcessing: 'Tekrar dene',
    labelButtonProcessItem: 'Yükle',
    labelMaxFileSizeExceeded: 'Dosya çok büyük',
    labelMaxFileSize: 'En fazla dosya boyutu: {filesize}',
    labelMaxTotalFileSizeExceeded: 'Maximum boyut aşıldı',
    labelMaxTotalFileSize: 'Maximum dosya boyutu :{filesize}',
    labelFileTypeNotAllowed: 'Geçersiz dosya tipi',
    fileValidateTypeLabelExpectedTypes: 'Şu {allButLastType} ya da şu dosya olması gerekir: {lastType}',
    imageValidateSizeLabelFormatError: 'Resim tipi desteklenmiyor',
    imageValidateSizeLabelImageSizeTooSmall: 'Resim çok küçük',
    imageValidateSizeLabelImageSizeTooBig: 'Resim çok büyük',
    imageValidateSizeLabelExpectedMinSize: 'Minimum boyut {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'Maximum boyut {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'Çözünürlük çok düşük',
    imageValidateSizeLabelImageResolutionTooHigh: 'Çözünürlük çok yüksek',
    imageValidateSizeLabelExpectedMinResolution: 'Minimum çözünürlük {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'Maximum çözünürlük {maxResolution}'
};
