<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8" />
        <title>File Upload</title>
        {% load static %}
        {{ form.media }}
    </head>
    <body>
        <h1>Upload Files</h1>
        <form method="post"
              enctype="multipart/form-data"
              action="{% url 'upload' %}">
            {% csrf_token %}
            {{ form.as_p }}
            <button type="submit">Upload</button>
        </form>
    </body>
</html>
