export default {
    labelIdle: 'Natiahnúť súbor (drag&drop) alebo <span class="filepond--label-action"> Vyhľadať </span>',
    labelInvalidField: 'Pole obsahuje chybné súbory',
    labelFileWaitingForSize: 'Zisťuje sa veľkosť',
    labelFileSizeNotAvailable: 'Neznáma veľkosť',
    labelFileLoading: 'Prenáša sa',
    labelFileLoadError: 'Chyba pri prenose',
    labelFileProcessing: 'Prebieha upload',
    labelFileProcessingComplete: 'Upload dokončený',
    labelFileProcessingAborted: 'Upload stornovaný',
    labelFileProcessingError: 'Chyba pri uploade',
    labelFileProcessingRevertError: 'Chyba pri obnove',
    labelFileRemoveError: 'Chyba pri odstránení',
    labelTapToCancel: 'Kliknite pre storno',
    labelTapToRetry: 'Kliknite pre opakovanie',
    labelTapToUndo: 'Kliknite pre vrátenie',
    labelButtonRemoveItem: 'Odstrániť',
    labelButtonAbortItemLoad: 'Storno',
    labelButtonRetryItemLoad: 'Opakovať',
    labelButtonAbortItemProcessing: 'Späť',
    labelButtonUndoItemProcessing: 'Vrátiť',
    labelButtonRetryItemProcessing: 'Opakovať',
    labelButtonProcessItem: 'Upload',
    labelMaxFileSizeExceeded: 'Súbor je príliš veľký',
    labelMaxFileSize: 'Najväčšia veľkosť súboru je {filesize}',
    labelMaxTotalFileSizeExceeded: 'Prekročená maximálna celková veľkosť súboru',
    labelMaxTotalFileSize: 'Maximálna celková veľkosť súboru je {filesize}',
    labelFileTypeNotAllowed: 'Súbor je nesprávneho typu',
    fileValidateTypeLabelExpectedTypes: 'Očakáva sa {allButLastType} alebo {lastType}',
    imageValidateSizeLabelFormatError: 'Obrázok tohto typu nie je podporovaný',
    imageValidateSizeLabelImageSizeTooSmall: 'Obrázok je príliš malý',
    imageValidateSizeLabelImageSizeTooBig: 'Obrázok je príliš veľký',
    imageValidateSizeLabelExpectedMinSize: 'Minimálny rozmer je {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'Maximálny rozmer je {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'Rozlíšenie je príliš malé',
    imageValidateSizeLabelImageResolutionTooHigh: 'Rozlišenie je príliš veľké',
    imageValidateSizeLabelExpectedMinResolution: 'Minimálne rozlíšenie je {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'Maximálne rozlíšenie je {maxResolution}'
};
