export default {
    labelIdle: 'גרור ושחרר את הקבצים כאן או <span class="filepond--label-action"> לחץ כאן לבחירה </span>',
    labelInvalidField: 'קובץ לא חוקי',
    labelFileWaitingForSize: 'מחשב את גודל הקבצים',
    labelFileSizeNotAvailable: 'לא ניתן לקבוע את גודל הקבצים',
    labelFileLoading: 'טוען...',
    labelFileLoadError: 'שגיאה ארעה בעת טעינת הקבצים',
    labelFileProcessing: 'מעלה את הקבצים',
    labelFileProcessingComplete: 'העלאת הקבצים הסתיימה',
    labelFileProcessingAborted: 'העלאת הקבצים בוטלה',
    labelFileProcessingError: 'שגיאה ארעה בעת העלאת הקבצים',
    labelFileProcessingRevertError: 'שגיאה ארעה בעת שחזור הקבצים',
    labelFileRemoveError: 'שגיאה ארעה בעת הסרת הקובץ',
    labelTapToCancel: 'הקלק לביטול',
    labelTapToRetry: 'הקלק לנסות שנית',
    labelTapToUndo: 'הקלק לשחזר',
    labelButtonRemoveItem: 'הסר',
    labelButtonAbortItemLoad: 'בטל',
    labelButtonRetryItemLoad: 'טען שנית',
    labelButtonAbortItemProcessing: 'בטל',
    labelButtonUndoItemProcessing: 'שחזר',
    labelButtonRetryItemProcessing: 'נסה שנית',
    labelButtonProcessItem: 'העלה קובץ',
    labelMaxFileSizeExceeded: 'הקובץ גדול מדי',
    labelMaxFileSize: 'גודל המירבי המותר הוא: {filesize}',
    labelMaxTotalFileSizeExceeded: 'גודל הקבצים חורג מהכמות המותרת',
    labelMaxTotalFileSize: 'הגודל המירבי של סך הקבצים: {filesize}',
    labelFileTypeNotAllowed: 'קובץ מסוג זה אינו מותר',
    fileValidateTypeLabelExpectedTypes: 'הקבצים המותרים הם {allButLastType} או {lastType}',
    imageValidateSizeLabelFormatError: 'תמונה בפורמט זה אינה נתמכת',
    imageValidateSizeLabelImageSizeTooSmall: 'תמונה זו קטנה מדי',
    imageValidateSizeLabelImageSizeTooBig: 'תמונה זו גדולה מדי',
    imageValidateSizeLabelExpectedMinSize: 'הגודל צריך להיות לפחות: {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'הגודל המרבי המותר: {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'הרזולוציה של תמונה זו נמוכה מדי',
    imageValidateSizeLabelImageResolutionTooHigh: 'הרזולוציה של תמונה זו גבוהה מדי',
    imageValidateSizeLabelExpectedMinResolution: 'הרזולוציה צריכה להיות לפחות: {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'הרזולוציה המירבית המותרת היא: {maxResolution}',
};
