export default {
    labelIdle: 'Lohista oma failid siia või <span class="filepond--label-action"> Sirvi </span>',
    labelInvalidField: 'Väli sisaldab kehtetuid faile',
    labelFileWaitingForSize: 'Ootab suurust',
    labelFileSizeNotAvailable: 'Suurus pole saadaval',
    labelFileLoading: 'Laadimine',
    labelFileLoadError: 'Viga laadimisel',
    labelFileProcessing: 'Üleslaadimine',
    labelFileProcessingComplete: 'Üleslaadimine lõpetatud',
    labelFileProcessingAborted: 'Üleslaadimine tühistatud',
    labelFileProcessingError: 'Viga üleslaadimisel',
    labelFileProcessingRevertError: 'Viga tagasivõtmisel',
    labelFileRemoveError: 'Viga eemaldamisel',
    labelTapToCancel: 'katkesta puudutades',
    labelTapToRetry: 'proovi uuesti puudutades',
    labelTapToUndo: 'võta tagasi puudutades',
    labelButtonRemoveItem: 'Eemalda',
    labelButtonAbortItemLoad: 'Katkesta',
    labelButtonRetryItemLoad: 'Proovi uuesti',
    labelButtonAbortItemProcessing: 'Tühista',
    labelButtonUndoItemProcessing: 'Võta tagasi',
    labelButtonRetryItemProcessing: 'Proovi uuesti',
    labelButtonProcessItem: 'Lae üles',
    labelMaxFileSizeExceeded: 'Fail on liiga suur',
    labelMaxFileSize: 'Maksimaalne faili suurus on {filesize}',
    labelMaxTotalFileSizeExceeded: 'Maksimaalne kogusuurus ületatud',
    labelMaxTotalFileSize: 'Maksimaalne kogu faili suurus on {filesize}',
    labelFileTypeNotAllowed: 'Keelatud failitüüp',
    fileValidateTypeLabelExpectedTypes: 'Oodatakse {allButLastType} või {lastType}',
    imageValidateSizeLabelFormatError: 'Pildi formaat ei ole toetatud',
    imageValidateSizeLabelImageSizeTooSmall: 'Pilt on liiga väike',
    imageValidateSizeLabelImageSizeTooBig: 'Pilt on liiga suur',
    imageValidateSizeLabelExpectedMinSize: 'Minimaalne suurus on {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'Maksimaalne suurus on {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'Resolutsioon on liiga madal',
    imageValidateSizeLabelImageResolutionTooHigh: 'Resolutsioon on liiga kõrge',
    imageValidateSizeLabelExpectedMinResolution: 'Minimaalne resolutsioon on {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'Maksimaalne resolutsioon on {maxResolution}'
};
