export default {
    labelIdle: 'Σύρετε τα αρχεία σας στο πλαίσιο ή <span class="filepond--label-action"> Επιλέξτε </span>',
    labelInvalidField: 'Το πεδίο περιέχει μη έγκυρα αρχεία',
    labelFileWaitingForSize: 'Σε αναμονή για το μέγεθος',
    labelFileSizeNotAvailable: 'Μέγεθος μη διαθέσιμο',
    labelFileLoading: 'Φόρτωση σε εξέλιξη',
    labelFileLoadError: 'Σφάλμα κατά τη φόρτωση',
    labelFileProcessing: 'Επεξεργασία',
    labelFileProcessingComplete: 'Η επεξεργασία ολοκληρώθηκε',
    labelFileProcessingAborted: 'Η επεξεργασία ακυρώθηκε',
    labelFileProcessingError: 'Σφάλμα κατά την επεξεργασία',
    labelFileProcessingRevertError: 'Σφάλμα κατά την επαναφορά',
    labelFileRemoveError: 'Σφάλμα κατά την διαγραφή',
    labelTapToCancel: 'πατήστε για ακύρωση',
    labelTapToRetry: 'πατήστε για επανάληψη',
    labelTapToUndo: 'πατήστε για αναίρεση',
    labelButtonRemoveItem: 'Αφαίρεση',
    labelButtonAbortItemLoad: 'Ακύρωση',
    labelButtonRetryItemLoad: 'Επανάληψη',
    labelButtonAbortItemProcessing: 'Ακύρωση',
    labelButtonUndoItemProcessing: 'Αναίρεση',
    labelButtonRetryItemProcessing: 'Επανάληψη',
    labelButtonProcessItem: 'Μεταφόρτωση',
    labelMaxFileSizeExceeded: 'Το αρχείο είναι πολύ μεγάλο',
    labelMaxFileSize: 'Το μέγιστο μέγεθος αρχείου είναι {filesize}',
    labelMaxTotalFileSizeExceeded: 'Υπέρβαση του μέγιστου συνολικού μεγέθους',
    labelMaxTotalFileSize: 'Το μέγιστο συνολικό μέγεθος αρχείων είναι {filesize}',
    labelFileTypeNotAllowed: 'Μη έγκυρος τύπος αρχείου',
    fileValidateTypeLabelExpectedTypes: 'Τα αποδεκτά αρχεία είναι {allButLastType} ή {lastType}',
    imageValidateSizeLabelFormatError: 'Ο τύπος της εικόνας δεν υποστηρίζεται',
    imageValidateSizeLabelImageSizeTooSmall: 'Η εικόνα είναι πολύ μικρή',
    imageValidateSizeLabelImageSizeTooBig: 'Η εικόνα είναι πολύ μεγάλη',
    imageValidateSizeLabelExpectedMinSize: 'Το ελάχιστο αποδεκτό μέγεθος είναι {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'Το μέγιστο αποδεκτό μέγεθος είναι {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'Η ανάλυση της εικόνας είναι πολύ χαμηλή',
    imageValidateSizeLabelImageResolutionTooHigh: 'Η ανάλυση της εικόνας είναι πολύ υψηλή',
    imageValidateSizeLabelExpectedMinResolution: 'Η ελάχιστη αποδεκτή ανάλυση είναι {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'Η μέγιστη αποδεκτή ανάλυση είναι {maxResolution}'
};
